@@ -454,6 +454,7 @@ def file_selection(
         if action in (
             Gtk.FileChooserAction.SAVE,
                 Gtk.FileChooserAction.CREATE_FOLDER):
+            filename = _slugify_filename(filename)
             win.set_current_name(filename)
         else:
             win.set_filename(filename)
@@ -508,15 +509,19 @@ def slugify(value):
     return _slugify_hyphenate_re.sub('-', value)
 
 
-def file_write(filename, data):
-    if isinstance(data, str):
-        data = data.encode('utf-8')
-    dtemp = tempfile.mkdtemp(prefix='gnuhealth_')
+def _slugify_filename(filename):
     if not isinstance(filename, str):
         name, ext = filename
     else:
         name, ext = os.path.splitext(filename)
-    filename = ''.join([slugify(name), os.extsep, slugify(ext)])
+    return ''.join([slugify(name), os.extsep, slugify(ext)])
+
+
+def file_write(filename, data):
+    if isinstance(data, str):
+        data = data.encode('utf-8')
+    dtemp = tempfile.mkdtemp(prefix='gnuhealth_')
+    filename = _slugify_filename(filename)
     filepath = os.path.join(dtemp, filename)
     with open(filepath, 'wb') as fp:
         fp.write(data)
@@ -1355,3 +1360,16 @@ def idle_add(func):
 def setup_window(window):
     if sys.platform == 'darwin':
         window.set_mnemonic_modifier(Gdk.ModifierType.CONTROL_MASK)
+
+def get_gdk_backend():
+    if sys.platform == 'darwin':
+        return 'macos'
+    elif sys.platform == 'win32':
+        return 'win32'
+    else:
+        dm = Gdk.DisplayManager.get()
+        default = dm.props.default_display
+        dm_class_name = default.__class__.__name__.lower()
+        if 'wayland' in dm_class_name:
+            return 'wayland'
+        return 'x11'
