@@ -990,7 +990,9 @@ class ViewTree(View):
 
     def __select_changed(self, tree_sel):
         previous_record = self.record
-        if previous_record and previous_record not in previous_record.group:
+        if (previous_record
+                and (previous_record not in previous_record.group
+                    or previous_record.destroyed)):
             previous_record = None
 
         if tree_sel.get_mode() == Gtk.SelectionMode.SINGLE:
@@ -1187,7 +1189,8 @@ class ViewTree(View):
             records.append(model.get_value(iter_, 0))
         records = []
         sel = self.treeview.get_selection()
-        sel.selected_foreach(_func_sel_get, records)
+        if sel is not None:
+            sel.selected_foreach(_func_sel_get, records)
         return records
 
     def get_selected_paths(self):
